@@ -19,6 +19,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *================================================================*/
 
+#include <stdlib.h>
 #include <stdio.h>
 #include <unistd.h>
 #include <sys/time.h>
@@ -27,11 +28,10 @@
 #include <fcntl.h>
 #ifdef __FreeBSD__
 #  include <machine/soundcard.h>
-#  include <awe_voice.h>
 #elif defined(linux)
 #  include <linux/soundcard.h>
-#  include <linux/awe_voice.h>
 #endif
+#include <awe_voice.h>
 #include <util.h>
 #include "seq.h"
 
